==> play.it_2.26.3.orig.tar.gz: src/10_common/20_temporary-directories.sh <==
# set temporary directories
# USAGE: set_temp_directories
set_temp_directories() {
	debug_entering_function 'set_temp_directories'

	# Get path to temporary directory
	local temporary_directory_path
	temporary_directory_path=$(temporary_directory_path)

	# Check that the given path is valid for temporary files storage
	temporary_directory_checks "$temporary_directory_path"

	# Generate a directory with a unique name for the current instance
	local game_id
	game_id=$(game_id)
	PLAYIT_WORKDIR=$(mktemp --directory --tmpdir="$temporary_directory_path" "${game_id}.XXXXX")
	## Ensure that we are always using an absolute path for PLAYIT_WORKDIR,
	## to avoid issues when a relative path has been used with the ./play.it --tmpdir option.
	PLAYIT_WORKDIR=$(realpath "$PLAYIT_WORKDIR")
	debug_creating_directory "$PLAYIT_WORKDIR"
	export PLAYIT_WORKDIR

	# Export the path to the packages to build as PKG_xxx_PATH
	# Some game scripts are expecting this variable to be set
	# These should be updated to call `package_path` instead
	local packages_list package package_path
	packages_list=$(packages_get_list)
	for package in $packages_list; do
		package_path=$(package_path "$package")
		eval "${package}_PATH='${package_path}'"
		export "${package?}_PATH"
	done

	debug_leaving_function 'set_temp_directories'
}

# Print the path to the temporary directory to use
# USAGE: temporary_directory_path
temporary_directory_path() {
	option_value 'tmpdir'
}

# Run checks on the path used for temporary files
# USAGE: temporary_directory_checks $temporary_directory_path
temporary_directory_checks() {
	local temporary_directory_path
	temporary_directory_path="$1"

	# Check that the given path is an existing directory
	if [ ! -d "$temporary_directory_path" ]; then
		error_temporary_path_not_a_directory "$temporary_directory_path"
		return 1
	fi

	# Check that the given path is writable
	if [ ! -w "$temporary_directory_path" ]; then
		error_temporary_path_not_writable "$temporary_directory_path"
		return 1
	fi

	# Check that the given path is on a case-sensitive filesystem
	if ! check_directory_is_case_sensitive "$temporary_directory_path"; then
		error_temporary_path_not_case_sensitive "$temporary_directory_path"
		return 1
	fi

	# Check that the given path is on a filesystem with support for UNIX permissions
	if ! check_directory_supports_unix_permissions "$temporary_directory_path"; then
		error_temporary_path_no_unix_permissions "$temporary_directory_path"
		return 1
	fi

	# Check that the given path has allow use of the execution bit
	if ! check_directory_supports_executable_files "$temporary_directory_path"; then
		error_temporary_path_noexec "$temporary_directory_path"
		return 1
	fi

	# Check that there is enough free space under the given path
	local option_free_space_check
	option_free_space_check=$(option_value 'free-space-check')
	if [ "$option_free_space_check" -eq 1 ]; then
		temporary_directory_check_free_space "$temporary_directory_path"
	fi
}

# Check that there is enough free space under the given path
# USAGE: temporary_directory_check_free_space $path
# RETURN: 0 if there is enough space,
#         1 otherwise
temporary_directory_check_free_space() {
	local path
	path="$1"

	# Compute the total size of the archives contents
	local free_space_required archives_list archive archive_size
	free_space_required=0
	archives_list=$(archives_used_list)
	for archive in $archives_list; do
		archive_size=$(archive_size "$archive")
		free_space_required=$((free_space_required + archive_size))
	done

	# Compare the free space available with twice the archives contents size
	local df_options free_space_available free_space_required_double
	df_options='--block-size=1K --output=avail'
	free_space_available=$(LANG=C df $df_options "$path" | tail --lines=1)
	free_space_required_double=$((free_space_required * 2))
	if [ "$free_space_available" -lt "$free_space_required_double" ]; then
		error_temporary_path_not_enough_space "$path"
		return 1
	fi
}

==> play.it_2.27.1.orig.tar.gz: src/10_common/20_temporary-directories.sh <==
# set temporary directories
# USAGE: set_temp_directories
set_temp_directories() {
	debug_entering_function 'set_temp_directories'

	# Get path to temporary directory
	local temporary_directory_path
	temporary_directory_path=$(temporary_directory_path)

	# Check that the given path is valid for temporary files storage
	temporary_directory_checks "$temporary_directory_path"

	# Generate a directory with a unique name for the current instance
	local game_id
	game_id=$(game_id)
	PLAYIT_WORKDIR=$(mktemp --directory --tmpdir="$temporary_directory_path" "${game_id}.XXXXX")
	## Ensure that we are always using an absolute path for PLAYIT_WORKDIR,
	## to avoid issues when a relative path has been used with the ./play.it --tmpdir option.
	PLAYIT_WORKDIR=$(realpath "$PLAYIT_WORKDIR")
	debug_creating_directory "$PLAYIT_WORKDIR"
	export PLAYIT_WORKDIR

	# Export the path to the packages to build as PKG_xxx_PATH
	# Some game scripts are expecting this variable to be set
	# These should be updated to call `package_path` instead
	local packages_list package package_path
	packages_list=$(packages_list)
	for package in $packages_list; do
		package_path=$(package_path "$package")
		eval "${package}_PATH='${package_path}'"
		export "${package?}_PATH"
	done

	debug_leaving_function 'set_temp_directories'
}

# Print the path to the temporary directory to use
# USAGE: temporary_directory_path
temporary_directory_path() {
	option_value 'tmpdir'
}

# Run checks on the path used for temporary files
# USAGE: temporary_directory_checks $temporary_directory_path
temporary_directory_checks() {
	local temporary_directory_path
	temporary_directory_path="$1"

	# Check that the given path is an existing directory
	if [ ! -d "$temporary_directory_path" ]; then
		error_temporary_path_not_a_directory "$temporary_directory_path"
		return 1
	fi

	# Check that the given path is writable
	if [ ! -w "$temporary_directory_path" ]; then
		error_temporary_path_not_writable "$temporary_directory_path"
		return 1
	fi

	# Check that the given path is on a case-sensitive filesystem
	if ! check_directory_is_case_sensitive "$temporary_directory_path"; then
		error_temporary_path_not_case_sensitive "$temporary_directory_path"
		return 1
	fi

	# Check that the given path is on a filesystem with support for UNIX permissions
	if ! check_directory_supports_unix_permissions "$temporary_directory_path"; then
		error_temporary_path_no_unix_permissions "$temporary_directory_path"
		return 1
	fi

	# Check that the given path has allow use of the execution bit
	if ! check_directory_supports_executable_files "$temporary_directory_path"; then
		error_temporary_path_noexec "$temporary_directory_path"
		return 1
	fi

	# Check that there is enough free space under the given path
	local option_free_space_check
	option_free_space_check=$(option_value 'free-space-check')
	if [ "$option_free_space_check" -eq 1 ]; then
		temporary_directory_check_free_space "$temporary_directory_path"
	fi
}

# Check that there is enough free space under the given path
# USAGE: temporary_directory_check_free_space $path
# RETURN: 0 if there is enough space,
#         1 otherwise
temporary_directory_check_free_space() {
	local path
	path="$1"

	# Compute the total size of the archives contents
	local free_space_required archives_list archive archive_size
	free_space_required=0
	archives_list=$(archives_used_list)
	for archive in $archives_list; do
		archive_size=$(archive_size "$archive")
		free_space_required=$((free_space_required + archive_size))
	done

	# Compare the free space available with twice the archives contents size
	local df_options free_space_available free_space_required_double
	df_options='--block-size=1K --output=avail'
	free_space_available=$(env --ignore-environment df $df_options "$path" | tail --lines=1)
	free_space_required_double=$((free_space_required * 2))
	if [ "$free_space_available" -lt "$free_space_required_double" ]; then
		error_temporary_path_not_enough_space "$path"
		return 1
	fi
}
